pub struct Axis<'a> {
data: FontData<'a>,
}Expand description
Fields
data: FontData<'a>Implementations
Sourceimpl<'a> Axis<'a>
impl<'a> Axis<'a>
pub const MIN_SIZE: usize
Sourcepub fn resolve_offset<O: Offset, R: FontRead<'a>>(
&self,
offset: O,
) -> Result<R, ReadError>
pub fn resolve_offset<O: Offset, R: FontRead<'a>>( &self, offset: O, ) -> Result<R, ReadError>
Resolve the provided offset from the start of this table.
Sourcepub fn offset_data(&self) -> FontData<'a>
pub fn offset_data(&self) -> FontData<'a>
Return a reference to this table’s raw data.
We use this in the compile crate to resolve offsets.
Sourcepub fn shape(&self) -> &Self
👎Deprecated: just use the base type directly
pub fn shape(&self) -> &Self
Return a reference to the table’s ‘Shape’ struct.
This is a low level implementation detail, but it can be useful in some cases where you want to know things about a table’s layout, such as the byte offsets of specific fields.
Sourcepub fn base_tag_list_offset(&self) -> Nullable<Offset16>
pub fn base_tag_list_offset(&self) -> Nullable<Offset16>
Offset to BaseTagList table, from beginning of Axis table (may be NULL)
Sourcepub fn base_tag_list(&self) -> Option<Result<BaseTagList<'a>, ReadError>>
pub fn base_tag_list(&self) -> Option<Result<BaseTagList<'a>, ReadError>>
Attempt to resolve base_tag_list_offset.
Sourcepub fn base_script_list_offset(&self) -> Offset16
pub fn base_script_list_offset(&self) -> Offset16
Offset to BaseScriptList table, from beginning of Axis table
Sourcepub fn base_script_list(&self) -> Result<BaseScriptList<'a>, ReadError>
pub fn base_script_list(&self) -> Result<BaseScriptList<'a>, ReadError>
Attempt to resolve base_script_list_offset.
pub fn base_tag_list_offset_byte_range(&self) -> Range<usize> ⓘ
pub fn base_script_list_offset_byte_range(&self) -> Range<usize> ⓘ