pub struct Base<'a> {
data: FontData<'a>,
}Expand description
The BASE (Baseline) table
Fields
data: FontData<'a>Implementations
Sourceimpl<'a> Base<'a>
impl<'a> Base<'a>
pub const MIN_SIZE: usize
Sourcepub fn resolve_offset<O: Offset, R: FontRead<'a>>(
&self,
offset: O,
) -> Result<R, ReadError>
pub fn resolve_offset<O: Offset, R: FontRead<'a>>( &self, offset: O, ) -> Result<R, ReadError>
Resolve the provided offset from the start of this table.
Sourcepub fn offset_data(&self) -> FontData<'a>
pub fn offset_data(&self) -> FontData<'a>
Return a reference to this table’s raw data.
We use this in the compile crate to resolve offsets.
Sourcepub fn shape(&self) -> &Self
👎Deprecated: just use the base type directly
pub fn shape(&self) -> &Self
Return a reference to the table’s ‘Shape’ struct.
This is a low level implementation detail, but it can be useful in some cases where you want to know things about a table’s layout, such as the byte offsets of specific fields.
Sourcepub fn version(&self) -> MajorMinor
pub fn version(&self) -> MajorMinor
(major, minor) Version for the BASE table (1,0) or (1,1)
Sourcepub fn horiz_axis_offset(&self) -> Nullable<Offset16>
pub fn horiz_axis_offset(&self) -> Nullable<Offset16>
Offset to horizontal Axis table, from beginning of BASE table (may be NULL)
Sourcepub fn horiz_axis(&self) -> Option<Result<Axis<'a>, ReadError>>
pub fn horiz_axis(&self) -> Option<Result<Axis<'a>, ReadError>>
Attempt to resolve horiz_axis_offset.
Sourcepub fn vert_axis_offset(&self) -> Nullable<Offset16>
pub fn vert_axis_offset(&self) -> Nullable<Offset16>
Offset to vertical Axis table, from beginning of BASE table (may be NULL)
Sourcepub fn vert_axis(&self) -> Option<Result<Axis<'a>, ReadError>>
pub fn vert_axis(&self) -> Option<Result<Axis<'a>, ReadError>>
Attempt to resolve vert_axis_offset.
Sourcepub fn item_var_store_offset(&self) -> Option<Nullable<Offset32>>
pub fn item_var_store_offset(&self) -> Option<Nullable<Offset32>>
Offset to Item Variation Store table, from beginning of BASE table (may be null)
Sourcepub fn item_var_store(
&self,
) -> Option<Result<ItemVariationStore<'a>, ReadError>>
pub fn item_var_store( &self, ) -> Option<Result<ItemVariationStore<'a>, ReadError>>
Attempt to resolve item_var_store_offset.