pub struct BaseCoordFormat3<'a> {
data: FontData<'a>,
}Expand description
Fields
data: FontData<'a>Implementations
Sourceimpl<'a> BaseCoordFormat3<'a>
impl<'a> BaseCoordFormat3<'a>
pub const MIN_SIZE: usize
Sourcepub fn resolve_offset<O: Offset, R: FontRead<'a>>(
&self,
offset: O,
) -> Result<R, ReadError>
pub fn resolve_offset<O: Offset, R: FontRead<'a>>( &self, offset: O, ) -> Result<R, ReadError>
Resolve the provided offset from the start of this table.
Sourcepub fn offset_data(&self) -> FontData<'a>
pub fn offset_data(&self) -> FontData<'a>
Return a reference to this table’s raw data.
We use this in the compile crate to resolve offsets.
Sourcepub fn shape(&self) -> &Self
👎Deprecated: just use the base type directly
pub fn shape(&self) -> &Self
Return a reference to the table’s ‘Shape’ struct.
This is a low level implementation detail, but it can be useful in some cases where you want to know things about a table’s layout, such as the byte offsets of specific fields.
Sourcepub fn base_coord_format(&self) -> u16
pub fn base_coord_format(&self) -> u16
Format identifier — format = 3
Sourcepub fn coordinate(&self) -> i16
pub fn coordinate(&self) -> i16
X or Y value, in design units
Sourcepub fn device_offset(&self) -> Nullable<Offset16>
pub fn device_offset(&self) -> Nullable<Offset16>
Offset to Device table (non-variable font) / Variation Index table (variable font) for X or Y value, from beginning of BaseCoord table (may be NULL).
Sourcepub fn device(&self) -> Option<Result<DeviceOrVariationIndex<'a>, ReadError>>
pub fn device(&self) -> Option<Result<DeviceOrVariationIndex<'a>, ReadError>>
Attempt to resolve device_offset.
pub fn base_coord_format_byte_range(&self) -> Range<usize> ⓘ
pub fn coordinate_byte_range(&self) -> Range<usize> ⓘ
pub fn device_offset_byte_range(&self) -> Range<usize> ⓘ