pub struct BaseScript<'a> {
data: FontData<'a>,
}Expand description
Fields
data: FontData<'a>Implementations
Sourceimpl<'a> BaseScript<'a>
impl<'a> BaseScript<'a>
pub const MIN_SIZE: usize
Sourcepub fn resolve_offset<O: Offset, R: FontRead<'a>>(
&self,
offset: O,
) -> Result<R, ReadError>
pub fn resolve_offset<O: Offset, R: FontRead<'a>>( &self, offset: O, ) -> Result<R, ReadError>
Resolve the provided offset from the start of this table.
Sourcepub fn offset_data(&self) -> FontData<'a>
pub fn offset_data(&self) -> FontData<'a>
Return a reference to this table’s raw data.
We use this in the compile crate to resolve offsets.
Sourcepub fn shape(&self) -> &Self
👎Deprecated: just use the base type directly
pub fn shape(&self) -> &Self
Return a reference to the table’s ‘Shape’ struct.
This is a low level implementation detail, but it can be useful in some cases where you want to know things about a table’s layout, such as the byte offsets of specific fields.
Sourcepub fn base_values_offset(&self) -> Nullable<Offset16>
pub fn base_values_offset(&self) -> Nullable<Offset16>
Offset to BaseValues table, from beginning of BaseScript table (may be NULL)
Sourcepub fn base_values(&self) -> Option<Result<BaseValues<'a>, ReadError>>
pub fn base_values(&self) -> Option<Result<BaseValues<'a>, ReadError>>
Attempt to resolve base_values_offset.
Sourcepub fn default_min_max_offset(&self) -> Nullable<Offset16>
pub fn default_min_max_offset(&self) -> Nullable<Offset16>
Offset to MinMax table, from beginning of BaseScript table (may be NULL)
Sourcepub fn default_min_max(&self) -> Option<Result<MinMax<'a>, ReadError>>
pub fn default_min_max(&self) -> Option<Result<MinMax<'a>, ReadError>>
Attempt to resolve default_min_max_offset.
Sourcepub fn base_lang_sys_count(&self) -> u16
pub fn base_lang_sys_count(&self) -> u16
Number of BaseLangSysRecords defined — may be zero (0)
Sourcepub fn base_lang_sys_records(&self) -> &'a [BaseLangSysRecord]
pub fn base_lang_sys_records(&self) -> &'a [BaseLangSysRecord]
Array of BaseLangSysRecords, in alphabetical order by BaseLangSysTag
pub fn base_values_offset_byte_range(&self) -> Range<usize> ⓘ
pub fn default_min_max_offset_byte_range(&self) -> Range<usize> ⓘ
pub fn base_lang_sys_count_byte_range(&self) -> Range<usize> ⓘ
pub fn base_lang_sys_records_byte_range(&self) -> Range<usize> ⓘ